@@ -120,6 +120,8 @@ combine.par.anneal <- function(a, b){
 #' adjacency list from a "SpatialPolygonsDataFrame" data type.
 #' Default is "rooks".
 #'
+#' @return list of class redist
+#'
 #' @concept simulate
 #' @export
 redist.flip.anneal <- function(adj,
@@ -325,7 +327,7 @@ redist.flip.anneal <- function(adj,
     ## Combine and save the data
     ## -------------------------
     if(!is.null(savename)){
-        saveRDS(algout, file = paste0(savename, ".RData"))
+        saveRDS(algout, file = paste0(savename, ".rds"))
     }
 
     ## Examine the data
@@ -635,7 +637,7 @@ redist.mcmc.anneal <- function(adj,
     ## Combine and save the data
     ## -------------------------
     if(!is.null(savename)){
-        saveRDS(algout, file = paste0(savename, ".RData"))
+        saveRDS(algout, file = paste0(savename, ".rds"))
     }
     
     ## Examine the data
@@ -653,6 +655,47 @@ redist.mcmc.anneal <- function(adj,
 #'
 #' @param file_name The file name to search for in current working directory.
 #'
+#' @return \code{redist.combine.anneal} returns an object of class "redist". The object
+#' \code{redist} is a list that contains the following components (the
+#' inclusion of some components is dependent on whether tempering
+#' techniques are used):
+#' \item{plans}{Matrix of congressional district assignments generated by the
+#' algorithm. Each row corresponds to a geographic unit, and each column
+#' corresponds to a simulation.}
+#' \item{distance_parity}{Vector containing the maximum distance from parity for
+#' a particular simulated redistricting plan.}
+#' \item{mhdecisions}{A vector specifying whether a proposed redistricting plan
+#' was accepted (1) or rejected (0) in a given iteration.}
+#' \item{mhprob}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm.}
+#' \item{pparam}{A vector containing the draw of the \code{p} parameter for each
+#' simulation, which dictates the number of swaps attempted.}
+#' \item{constraint_pop}{A vector containing the value of the population
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_compact}{A vector containing the value of the compactness
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_segregation}{A vector containing the value of the
+#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_vra}{A vector containing the value of the
+#' vra constraint for each accepted redistricting plan.}
+#' \item{constraint_similar}{A vector containing the value of the similarity
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_partisan}{A vector containing the value of the
+#' partisan constraint for each accepted redistricting plan.}
+#' \item{constraint_minority}{A vector containing the value of the
+#' minority constraint for each accepted redistricting plan.}
+#' \item{constraint_hinge}{A vector containing the value of the
+#' hinge constraint for each accepted redistricting plan.}
+#' \item{beta_sequence}{A vector containing the value of beta for each iteration
+#' of the algorithm. Returned when tempering is being used.}
+#' \item{mhdecisions_beta}{A vector specifying whether a proposed beta value was
+#' accepted (1) or rejected (0) in a given iteration of the algorithm. Returned
+#' when tempering is being used.}
+#' \item{mhprob_beta}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm. Returned when tempering
+#' is being used.}
+#'
+#'
 #' @concept post
 #' @export
 redist.combine.anneal <- function(file_name){
@@ -721,7 +764,7 @@ redist.combine.anneal <- function(file_name){
 #'
 #' @usage redist.combine(savename, nloop, nthin, temper)
 #'
-#' @param savename The name (without the loop or \code{.RData} suffix)
+#' @param savename The name (without the loop or \code{.rds} suffix)
 #' of the saved simulations.
 #' @param nloop The number of loops being combined. Savename must be non-null.
 #' @param nthin How much to thin the simulations being combined.
@@ -779,31 +822,31 @@ redist.combine.anneal <- function(file_name){
 #' @return  a redist object with entries combined
 #' 
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' data(fl25)
 #' data(fl25_enum)
 #' data(fl25_adj)
 #'
-#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,Imai and
-#' Tarr (2015)
+#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,Imai and Tarr (2015)
 #'
 #' ## Get an initial partition
 #' init_plan <- fl25_enum$plans[, 5118]
 #'
 #' ## Run the algorithm
+#' set.seed(1)
+#' temp <- tempdir()
 #' alg_253 <- redist.flip(adj = fl25_adj, total_pop = fl25$pop,
 #'                        init_plan = init_plan, nsims = 10000,
-#'                        loops = 2, savename = "test")
-#' out <- redist.combine(savename = "test", nloop = 2, nthin = 10)
+#'                        nloop = 2, savename = paste0(temp, "/test"))
+#' out <- redist.combine(savename = paste0(temp, "/test"), nloop = 2, nthin = 10)
 #' }
 #' @concept post
 #' @export
 redist.combine <- function(savename, nloop, nthin, temper = 0){
-
     ##############################
     ## Set up container objects ##
     ##############################
-    algout <- readRDS(paste0(savename, "_loop1.RData"))
+    algout <- readRDS(paste0(savename, "_loop1.rds"))
     names_obj <- names(algout)
 
     ## Create containers
@@ -826,7 +869,7 @@ redist.combine <- function(savename, nloop, nthin, temper = 0){
     for(i in 1:nloop){
 
         ## Load data
-        algout <- readRDS(paste0(savename, "_loop", i, ".RData"))
+        algout <- readRDS(paste0(savename, "_loop", i, ".rds"))
 
         ind <- ((i - 1) * (nc / nthin) + 1):(i * (nc / nthin))
 
@@ -862,7 +905,7 @@ redist.combine <- function(savename, nloop, nthin, temper = 0){
     #################
     ## Save object ##
     #################
-    saveRDS(algout, file = paste0(savename, ".RData"))
+    saveRDS(algout, file = paste0(savename, ".rds"))
 
     return(algout)
 }
@@ -1028,13 +1071,12 @@ redist.combine <- function(savename, nloop, nthin, temper = 0){
 #' \url{http://imai.princeton.edu/research/files/redist.pdf}.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' data(fl25)
 #' data(fl25_enum)
 #' data(fl25_adj)
 #'
-#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,Imai and
-#' Tarr (2015)
+#' ## Code to run the simulations in Figure 4 in Fifield, Higgins, Imai and Tarr (2015)
 #'
 #' ## Get an initial partition
 #' init_plan <- fl25_enum$plans[, 5118]
@@ -1049,6 +1091,7 @@ redist.combine <- function(savename, nloop, nthin, temper = 0){
 #'  
 #'  
 #' }
+#' 
 #' @concept simulate
 #' @export
 redist.flip <- function(adj,
@@ -1221,11 +1264,8 @@ redist.flip <- function(adj,
     ## Run the algorithm ##
     #######################
     for(i in loopstart:nloop){
-
         ## Get congressional districts, tempered beta values
         if(i > loopstart){
-            cat(i,'\n')
-
             cds <- algout$plans[,nsims]
 
             if(temper){
@@ -1233,7 +1273,7 @@ redist.flip <- function(adj,
             }
 
             if(!is.null(rngseed) & is.numeric(rngseed)){
-                .Random.seed <- algout$randseed
+                set.seed(algout$randseed)
             }
 
             rm(list = "algout")
@@ -1244,7 +1284,7 @@ redist.flip <- function(adj,
             if(loopstart > 1){
 
                 ## Load the data
-                algout <- readRDS(paste0(savename, "_loop", i - 1, ".RData"))
+                algout <- readRDS(paste0(savename, "_loop", i - 1, ".rds"))
 
                 ## Stop if number of simulations per loop is different
                 if(nsims != ncol(algout[[1]])){
@@ -1259,7 +1299,7 @@ redist.flip <- function(adj,
                 }
 
                 if(!is.null(rngseed) & is.numeric(rngseed)){
-                    .Random.seed <- algout$randseed
+                    set.seed(algout$randseed)
                 }
 
                 rm(list = "algout")
@@ -1318,12 +1358,12 @@ redist.flip <- function(adj,
 
         ## Save random number state if setting the seed
         if(!is.null(rngseed)){
-            algout$randseed <- .Random.seed
+            algout$randseed <- .Random.seed[3]
         }
 
         ## Save output
         if(nloop > 1){
-            saveRDS(algout, file = paste0(savename, "_loop", i, ".RData"))
+            saveRDS(algout, file = paste0(savename, "_loop", i, ".rds"))
         }
 
     }
@@ -1341,7 +1381,7 @@ redist.flip <- function(adj,
                        nthin = nthin,
                        temper = temperflag)
     }else if(!is.null(savename)){
-        saveRDS(algout, file = paste0(savename, ".RData"))
+        saveRDS(algout, file = paste0(savename, ".rds"))
     }
     
     ## Examine the data
@@ -1515,30 +1555,6 @@ redist.flip <- function(adj,
 #' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain Monte
 #' Carlo." Working Paper. Available at
 #' \url{http://imai.princeton.edu/research/files/redist.pdf}.
-#'
-#' @examples
-#' \dontrun{
-#' data(fl25)
-#' data(fl25_enum)
-#' data(fl25_adj)
-#'
-#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,Imai and
-#' Tarr (2015)
-#'
-#' ## Get an initial partition
-#' init_plan <- fl25_enum$plans[, 5118]
-#'
-#' ## Run the algorithm
-#' alg_253 <- redist.mcmc(adj = fl25_adj, total_pop = fl25$pop,
-#'                        init_plan = init_plan, nsims = 10000)
-#'  
-#'  ## You can also let it find a plan on its own!
-#'  sims <- redist.mcmc(adj = fl25_adj, total_pop = fl25$pop,
-#'                        ndists = 3, nsims = 10000)
-#'  
-#'  
-#' }
-#' 
 #' @rdname redist.flip
 #' @order 2
 #' 
@@ -1730,7 +1746,7 @@ redist.mcmc <- function(adj,
             }
             
             if(!is.null(rngseed) & is.numeric(rngseed)){
-                .Random.seed <- algout$randseed
+                set.seed(algout$randseed)
             }
             
             rm(list = "algout")
@@ -1741,7 +1757,7 @@ redist.mcmc <- function(adj,
             if(loopstart > 1){
                 
                 ## Load the data
-                algout <- readRDS(paste0(savename, "_loop", i - 1, ".RData"))
+                algout <- readRDS(paste0(savename, "_loop", i - 1, ".rds"))
                 
                 ## Stop if number of simulations per loop is different
                 if(nsims != ncol(algout[[1]])){
@@ -1756,7 +1772,7 @@ redist.mcmc <- function(adj,
                 }
                 
                 if(!is.null(rngseed) & is.numeric(rngseed)){
-                    .Random.seed <- algout$randseed
+                    set.seed(algout$randseed)
                 }
                 
                 rm(list = "algout")
@@ -1815,12 +1831,12 @@ redist.mcmc <- function(adj,
         
         ## Save random number state if setting the seed
         if(!is.null(rngseed)){
-            algout$randseed <- .Random.seed
+            algout$randseed <- .Random.seed[3]
         }
         
         ## Save output
         if(nloop > 1){
-            saveRDS(algout, file = paste0(savename, "_loop", i, ".RData"))
+            saveRDS(algout, file = paste0(savename, "_loop", i, ".rds"))
         }
         
     }
@@ -1838,7 +1854,7 @@ redist.mcmc <- function(adj,
                        nthin = nthin,
                        temper = temperflag)
     }else if(!is.null(savename)){
-        saveRDS(algout, file = paste0(savename, ".RData"))
+        saveRDS(algout, file = paste0(savename, ".rds"))
     }
     
     ## Examine the data
@@ -1860,10 +1876,6 @@ redist.mcmc <- function(adj,
 #' population parity, geographic compactness, or other constraints are
 #' implemented.
 #'
-#' @usage redist.ipw(algout,
-#' resampleconstraint = c("pop", "compact", "segregation", "similar"),
-#' targetbeta, targetpop = NULL, temper = 0)
-#'
 #' @param algout An object of class "redist".
 #' @param resampleconstraint The constraint implemented in the simulations: one
 #' of "pop", "compact", "segregation", or "similar".
@@ -1929,31 +1941,21 @@ redist.mcmc <- function(adj,
 #' when Fractions of Missing Information are Modest: the SIR Algorithm."
 #' Journal of the American Statistical Association.
 #'
-#' @examples \dontrun{
-#' data(fl25)
-#' data(fl25_enum)
-#' data(fl25_adj)
+#' @examples 
+#' \donttest{
+#' data(iowa)
+#' adj <- redist.adjacency(iowa)
+#' init_plan <- iowa$cd_2010
+#'alg <- redist.flip(adj = adj, total_pop = iowa$pop,
+#'                   init_plan = init_plan, nsims = 1000,
+#'                   constraint = 'population', constraintweights = 5.4)
 #'
-#' ## Code to run the simulations in Figure 4 of Fifield, Higgins,
-#' ## Imai and Tarr (2015)
-#'
-#' ## Get an initial partition
-#' init_plan <- fl25_enum$plans[, 5118]
-#'
-#' ## Vector of beta weights
-#' betaweights <- rep(NA, 10); for(i in 1:10){betaweights[i] <- 4^i}
-#'
-#' ## Run simulations - tempering population constraint
-#' alg_253_20_st <- redist.mcmc(adj = fl25_adj, total_pop = fl25$pop,
-#'                              init_plan = init_plan, nsims = 10000,
-#'                              constraint = 'population', constraintweights = 5.4,
-#'                              betaweights = betaweights, temper = 1)
-#'
-#' ## Resample using inverse probability weighting.
-#' ## Target distance from parity is 20%
-#' alg_253_20_st <- redist.ipw(alg_253_20_st, resampleconstraint = "pop",
-#'                             targetbeta = 1, targetpop = .2, temper = 1)
+#' alg_ipw <- redist.ipw(algout = alg, 
+#'                      resampleconstraint = 'pop', 
+#'                      targetbeta = 1,
+#'                      targetpop = 0.05)
 #' }
+#' 
 #' @concept post
 #' @export
 redist.ipw <- function(algout,
@@ -2008,10 +2010,13 @@ redist.ipw <- function(algout,
         ## Subset the matrix first, then the vectors
         if(i == 1){
             algout_new[[i]] <- algout[[i]][,inds]
-        }else{
+        } else if(length(algout[[i]]) == 1) {
+            algout_new[[i]] <- algout[[i]]
+        } else if(all(names(algout[[i]]) == 'adj')) {
+            algout_new[[i]] <- algout[[i]]
+        } else {
             algout_new[[i]] <- algout[[i]][inds]
         }
-
     }
     names(algout_new) <- names(algout)
 
