@@ -11,10 +11,13 @@
 #include <RcppArmadilloExtensions/sample.h>
 #include <time.h>
 #include <R.h>
+#include "redist_types.h"
 #include "sw_mh_helper.h"
 #include "make_swaps_helper.h"
 #include "constraint_calc_helper.h"
 #include "redist_analysis.h"
+#include "tree_op.h"
+
 
 using namespace Rcpp;
 
@@ -52,7 +55,7 @@ List swMH(List aList,
 	  NumericVector popvec,
 	  NumericVector grouppopvec,
 	  NumericVector areas_vec,
-	  NumericVector county_membership,
+	  IntegerVector county_membership,
 	  arma::mat borderlength_mat,
 	  int nsims,
 	  double eprob,
@@ -60,23 +63,34 @@ List swMH(List aList,
 	  NumericVector beta_sequence,
 	  NumericVector beta_weights,
 	  NumericMatrix ssdmat,
+	  double tgt_min,
+	  double tgt_other,
+	  IntegerVector rvote,
+	  IntegerVector dvote,
+	  NumericVector minorityprop,
 	  int lambda = 0,
 	  double beta = 0.0,
 	  double weight_population = 0.0,
 	  double weight_compact = 0.0,
 	  double weight_segregation = 0.0,
+	  double weight_vra = 0.0,
 	  double weight_similar = 0.0,
 	  double weight_countysplit = 0.0,
+	  double weight_partisan = 0.0,
+	  double weight_minority = 0.0,
+	  double weight_hinge = 0.0,
 	  std::string adapt_beta = "none",
 	  int adjswap = 1,
 	  int exact_mh = 0,
 	  int adapt_eprob = 0,
 	  int adapt_lambda = 0,
 	  std::string compactness_measure = "fryer-holden",
+	  std::string partisan_measure = "efficiency-gap",
 	  double ssd_denom = 1.0,
 	  int num_hot_steps = 0,
 	  int num_annealing_steps = 0,
-	  int num_cold_steps = 0)
+	  int num_cold_steps = 0,
+	  bool verbose = true)
 {
 
   /* Inputs to function:
@@ -106,22 +120,34 @@ List swMH(List aList,
      beta_population: strength of constraint for achieving population parity.
 
      beta_compact: strength of constraint for achieving district compactness
-
+   
      beta_segregation: strength of constraint for packing group into district
 
+     beta_vra: strength of constraint for packing group into district
+
      beta_similar: strength of constraint for examining plans similar to original district
+   
+   beta_partisan: strength of constraint for minimizing partisan bias measure
 
      anneal_beta_population: flag for whether to anneal the beta pop parameter
 
      anneal_beta_compact: flag for whether to anneal the beta compactness parameter
-
+   
      anneal_beta_segregation: flag for whether to anneal the beta segregation parameter
 
+     anneal_beta_vra: flag for whether to anneal the beta vra parameter
+
      anneal_beta_similar: flag for whether to anneal the beta similarity parameter
 
      adjswap: flag for whether to force algorithm to only do adjacent swaps
 
      exact_mh: flag for whether to calculate the exact metropolis-hastings w boundary correction
+   
+   partisan_measure: string, only "efficiency-gap" implemented thus far
+   
+   rvote: vote for Republicans (or Party A)
+   
+   dvote: vote for Democrats (or Party B != A)
 
   */
 
@@ -194,8 +220,12 @@ List swMH(List aList,
   NumericVector psipop_store(nsims);
   NumericVector psicompact_store(nsims);
   NumericVector psisegregation_store(nsims);
+  NumericVector psivra_store(nsims);
   NumericVector psisimilar_store(nsims);
   NumericVector psicountysplit_store(nsims);
+  NumericVector psipartisan_store(nsims);
+  NumericVector psiminority_store(nsims);
+  NumericVector psihinge_store(nsims);
 
   // Store value of p, lambda, weights for all simulations
   NumericVector pparam_store(nsims);
@@ -233,6 +263,8 @@ List swMH(List aList,
     Rcout << "-- Simulating at hot temperature." << std::endl;
     Rcout << "---------------------------------" << std::endl;
   }
+  
+  Graph g = list_to_graph(aList);
   // Open the simulations
   while(k < nsims){
 
@@ -294,10 +326,21 @@ List swMH(List aList,
 				   weight_population,
 				   weight_compact,
 				   weight_segregation,
+				   weight_vra,
 				   weight_similar,
 				   weight_countysplit,
+				   weight_partisan,
+				   weight_minority,
+				   weight_hinge,
 				   ssd_denom,
-				   compactness_measure);
+				   tgt_min,
+				   tgt_other,
+				   rvote,
+				   dvote,
+				   minorityprop,
+				   compactness_measure,
+				   partisan_measure,
+				   g);
 
     }while(as<int>(swap_partitions["goodprop"]) == 0);
 
@@ -334,7 +377,10 @@ List swMH(List aList,
 	psicompact_store[k] = swap_partitions["compact_new_psi"];
       }
       if(weight_segregation != 0.0){
-	psisegregation_store[k] = swap_partitions["segregation_new_psi"];
+        psisegregation_store[k] = swap_partitions["segregation_new_psi"];
+      }
+      if(weight_vra != 0.0){
+	psivra_store[k] = swap_partitions["vra_new_psi"];
       }
       if(weight_similar != 0.0){
 	psisimilar_store[k] = swap_partitions["similar_new_psi"];
@@ -342,6 +388,15 @@ List swMH(List aList,
       if(weight_countysplit != 0.0){
 	psicountysplit_store[k] = swap_partitions["countysplit_new_psi"];
       }
+      if(weight_partisan != 0.0){
+        psipartisan_store[k] = swap_partitions["partisan_new_psi"];
+      }
+      if(weight_minority != 0.0){
+        psiminority_store[k] = swap_partitions["minority_new_psi"];
+      }
+      if(weight_hinge != 0.0){
+        psihinge_store[k] = swap_partitions["hinge_new_psi"];
+      }
     }else{
       energy_store[k] = swap_partitions["energy_old"];
       if(weight_population != 0.0){
@@ -351,7 +406,10 @@ List swMH(List aList,
 	psicompact_store[k] = swap_partitions["compact_old_psi"];
       }
       if(weight_segregation != 0.0){
-	psisegregation_store[k] = swap_partitions["segregation_old_psi"];
+        psisegregation_store[k] = swap_partitions["segregation_old_psi"];
+      }
+      if(weight_vra != 0.0){
+	psivra_store[k] = swap_partitions["vra_old_psi"];
       }
       if(weight_similar != 0.0){
 	psisimilar_store[k] = swap_partitions["similar_old_psi"];
@@ -359,6 +417,15 @@ List swMH(List aList,
       if(weight_countysplit != 0.0){
 	psicountysplit_store[k] = swap_partitions["countysplit_old_psi"];
       }
+      if(weight_partisan != 0.0){
+        psipartisan_store[k] = swap_partitions["partisan_old_psi"];
+      }
+      if(weight_minority != 0.0){
+        psiminority_store[k] = swap_partitions["minority_old_psi"];
+      }
+      if(weight_hinge != 0.0){
+        psihinge_store[k] = swap_partitions["hinge_old_psi"];
+      }
     }
 
     /////////////////////////////////////////////////////////////
@@ -433,25 +500,31 @@ List swMH(List aList,
 
     // Print Progress
     if(k % nsims_10pct == 0){
-      Rcout << (double)k / nsims_10pct * 10 << " percent done." << std::endl;
-      if(adapt_lambda == 1){
-	Rcout << "Lambda: " << lambda << std::endl;
+      R_CheckUserInterrupt();
+      
+      if(verbose){
+        Rcout << (double)k / nsims_10pct * 10 << " percent done." << std::endl;
+        if(adapt_lambda == 1){
+          Rcout << "Lambda: " << lambda << std::endl;
+        }
+        if(adapt_eprob == 1){
+          Rcout << "Edgecut Probability: " << eprob << std::endl;
+        }
+        Rcout << "Metropolis acceptance ratio: "<< (double)decision_counter / (k-1) << std::endl << std::endl;
       }
-      if(adapt_eprob == 1){
-	Rcout << "Edgecut Probability: " << eprob << std::endl;
-      }
-      Rcout << "Metropolis acceptance ratio: "<< (double)decision_counter / (k-1) << std::endl << std::endl;
     }
     if(adapt_beta == "annealing"){
-      if(k == start_anneal){
-	Rcout << "----------------------------" << std::endl;
-	Rcout << "-- Starting annealing stage." << std::endl;
-	Rcout << "----------------------------" << std::endl;
-      }
-      if(k == start_cold){
-	Rcout << "----------------------------------" << std::endl;
-	Rcout << "-- Simulating at cold temperature." << std::endl;
-	Rcout << "----------------------------------" << std::endl;
+      if(verbose){
+        if(k == start_anneal){
+          Rcout << "----------------------------" << std::endl;
+          Rcout << "-- Starting annealing stage." << std::endl;
+          Rcout << "----------------------------" << std::endl;
+        }
+        if(k == start_cold){
+          Rcout << "----------------------------------" << std::endl;
+          Rcout << "-- Simulating at cold temperature." << std::endl;
+          Rcout << "----------------------------------" << std::endl;
+        }
       }
     }
 
@@ -497,7 +570,7 @@ List swMH(List aList,
   // Create list, store output
   List out;
   if(adapt_beta != "annealing"){
-    out["partitions"] = cd_store;
+    out["plans"] = cd_store;
     out["distance_parity"] = dist_parity_vec;
     out["distance_original"] = dist_orig_vec;
     out["mhdecisions"] = decision_store;
@@ -508,8 +581,12 @@ List swMH(List aList,
     out["constraint_pop"] = psipop_store;
     out["constraint_compact"] = psicompact_store;
     out["constraint_segregation"] = psisegregation_store;
+    out["constraint_vra"] = psivra_store;
     out["constraint_similar"] = psisimilar_store;
     out["constraint_countysplit"] = psicountysplit_store;
+    out["constraint_partisan"] = psipartisan_store;
+    out["constraint_minority"] = psiminority_store;
+    out["constraint_hinge"] = psihinge_store;
     out["boundary_partitions"] = boundarypartitions_store;
     out["boundaryratio"] = boundaryratio_store;
     if(adapt_beta == "tempering"){
@@ -523,7 +600,7 @@ List swMH(List aList,
       out["final_lambda"] = lambda;
     }
   }else{
-    out["partitions"] = cdvec;
+    out["plans"] = cdvec;
     out["distance_parity"] = dist_parity_vec[0];
     out["distance_original"] = dist_orig_vec[0];
     out["mhdecisions"] = decision_store[k-1];
@@ -534,8 +611,12 @@ List swMH(List aList,
     out["constraint_pop"] = psipop_store[k-1];
     out["constraint_compact"] = psicompact_store[k-1];
     out["constraint_segregation"] = psisegregation_store[k-1];
+    out["constraint_vra"] = psivra_store[k-1];
     out["constraint_similar"] = psisimilar_store[k-1];
     out["constraint_countysplit"] = psicountysplit_store[k-1];
+    out["constraint_partisan"] = psipartisan_store[k-1];
+    out["constraint_minority"] = psiminority_store[k-1];
+    out["constraint_hinge"] = psihinge_store[k-1];
     out["boundary_partitions"] = boundarypartitions_store[k-1];
     out["boundaryratio"] = boundaryratio_store[k-1];
     if(adapt_eprob == 1){
@@ -545,7 +626,10 @@ List swMH(List aList,
       out["final_lambda"] = lambda;
     }
   }
-
+  out["algorithm"] = "mcmc";
+  out["pct_dist_parity"] = pct_dist_parity;
+  out["nsims"] = nsims;
+  out["adj"] = aList;
   return out;
 
 }
